@@ -5,7 +5,7 @@ use Carp qw/croak confess carp/;
 
 BEGIN {
   $Math::Prime::Util::GMP::AUTHORITY = 'cpan:DANAJ';
-  $Math::Prime::Util::GMP::VERSION = '0.39';
+  $Math::Prime::Util::GMP::VERSION = '0.40';
 }
 
 # parent is cleaner, and in the Perl 5.10.1 / 5.12.0 core, but not earlier.
@@ -74,7 +74,8 @@ our @EXPORT_OK = qw(
                      totient
                      jordan_totient
                      carmichael_lambda
-                     is_power
+                     sqrtint rootint
+                     is_power is_prime_power
                      is_primitive_root
                      znorder
                      znprimroot
@@ -173,7 +174,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Möbius Deléglise Bézout gcdext vecsum vecprod moebius totient liouville znorder znprimroot bernfrac bernreal harmfrac harmreal stirling lucasu lucasv OpenPFGW gmpy2 nonresidue chinese tuplets sqrtmod addmod mulmod powmod divmod
+=for stopwords Möbius Deléglise Bézout gcdext vecsum vecprod moebius totient liouville znorder znprimroot bernfrac bernreal harmfrac harmreal stirling lucasu lucasv OpenPFGW gmpy2 nonresidue chinese tuplets sqrtmod addmod mulmod powmod divmod superset sqrtint rootint
 
 =head1 NAME
 
@@ -182,7 +183,7 @@ Math::Prime::Util::GMP - Utilities related to prime numbers and factoring, using
 
 =head1 VERSION
 
-Version 0.39
+Version 0.40
 
 
 =head1 SYNOPSIS
@@ -532,21 +533,37 @@ pseudoprimes than the extra-strong Lucas test.  However this is still only
 counterexamples have been found with any of the Lucas tests described.
 
 
+=head2 is_euler_plumb_pseudoprime
+
+Takes a positive number C<n> as input and returns 1 if C<n> passes
+Colin Plumb's Euler Criterion primality test.  Pseudoprimes to this test
+are a subset of the base 2 Fermat and Euler tests, but a superset
+of the base 2 strong pseudoprime (Miller-Rabin) test.
+
+The main reason for this test is that is a bit more efficient
+than other probable prime tests.
+
+
 =head2 is_perrin_pseudoprime
 
 Takes a positive number C<n> as input and returns 1 if C<n> divides C<P(n)>
 where C<P(n)> is the Perrin number of C<n>.  The Perrin sequence is defined by
+C<P(n) = P(n-2) + P(n-3)> with C<P(0) = 3, P(1) = 0, P(2) = 2>.
 
-   C<P(0) = 3, P(1) = 0, P(2) = 2;  P(n) = P(n-2) + P(n-3)>
-
-This is not a commonly used test, as it runs 5 to 10 times slower than most
+This is not a commonly used test, as it runs slower than most
 of the other probable prime tests and offers little benefit, especially over
-combined tests like L</is_bpsw_prime> and
-L</is_frobenius_underwood_pseudoprime>.
+combined tests like L</is_bpsw_prime>,
+L</is_frobenius_underwood_pseudoprime>, and
+L</is_frobenius_khashin_pseudoprime>.
 
-An optional second argument indicates whether to additionally test C<P(-n)>.
-Composites which pass this test are known as restricted Perrin pseudoprimes
-and are a subset of the unrestricted set.
+An optional second argument C<r> indicates whether to run additional tests.
+With C<r=1>, C<P(-n) = -1 mod n> is also verified, creating the
+"minimal restricted" test.
+With C<r=2>, the full signature is also tested using the Adams and Shanks (1982)
+rules (without the quadratic form test).
+With C<r=3>, the full signature is tested using the Grantham (2000) test, which
+additionally does not allow pseudoprimes to be divisible by 2 or 23.
+The minimal restricted pseudoprime sequence is L<OEIS A018187|http://oeis.org/A018187>.
 
 
 =head2 is_frobenius_pseudoprime
@@ -1306,6 +1323,25 @@ and 0 otherwise.  For example, if C<k=2> then this detects perfect squares.
 This corresponds to Pari/GP's C<ispower> function, with the limitations of
 only integer arguments and no third argument may be given to return the root.
 
+=head2 is_prime_power
+
+Given an integer input C<n>, returns C<k> if C<n = p^k> for some prime p,
+and zero otherwise.
+
+This corresponds to Pari/GP's C<isprimepower> function.
+
+=head2 sqrtint
+
+Returns the truncated integer part of the square root of C<n>.
+
+This corresponds to Pari/GP's C<sqrtint> function.
+
+=head2 rootint
+
+Given C<n> and C<k>, returns the truncated integer part of the C<k-th> root
+of C<n>.
+
+This corresponds to Pari/GP's C<sqrtnint> function.
 
 
 =head2 factor
